.. _templates_guide:

=========
Templates
=========

--------
Overview
--------

To test the functionalities of each tool, there are multiple templates avaliable to use them.

-----------------------
Mrs_spec_chan templates
-----------------------

The templates for this tool can be downloaded from this `first link`_.

.. _first link: https://cab.inta-csic.es/users/alabiano/templates_mrs_spec_chan.zip>

----------------------
Mrs_det_plot templates
----------------------

The templates for this tool can be downloaded from this `second link`_.

.. _second link: https://cab.inta-csic.es/users/alabiano/templates_mrs_det_plot.zip

------------------
Fit_line templates
------------------

The templates for this tool can be downloaded from this `third link`_.

.. _third link: https://cab.inta-csic.es/users/alabiano/templates_fit_line.zip. _third link: https://cab.inta-csic.es/users/alabiano/templates_fit_line.zip

.------------------
Cube_ans and mrs_subviz templates
------------------

The templates for this tool can be downloaded from this `fourth link`_.

.. _fourth link: https://cab.inta-csic.es/users/alabiano/templates_cubes.zip.
